==> apache-cloudstack-4.17.0.0-src.tar.bz2: apache-cloudstack-4.17.0.0-src/core/src/main/java/com/cloud/storage/template/TemplateConstants.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.storage.template;

public final class TemplateConstants {
    public static final String DEFAULT_TMPLT_ROOT_DIR = "template";
    public static final String DEFAULT_SNAPSHOT_ROOT_DIR = "snapshots";
    public static final String DEFAULT_VOLUME_ROOT_DIR = "volumes";
    public static final String DEFAULT_TMPLT_FIRST_LEVEL_DIR = "tmpl/";

    public static final String DEFAULT_SYSTEM_VM_TEMPLATE_PATH = "template/tmpl/1/";

    public static final String DEFAULT_SYSTEM_VM_TMPLT_NAME = "routing";

    public static final int DEFAULT_TMPLT_COPY_PORT = 80;
    public static final String DEFAULT_TMPLT_COPY_INTF = "eth2";

    public static final String DEFAULT_SSL_CERT_DOMAIN = "realhostip.com";
    public static final String DEFAULT_HTTP_AUTH_USER = "cloud";

}

==> apache-cloudstack-4.20.1.0-src.tar.bz2: apache-cloudstack-4.20.1.0-src/core/src/main/java/com/cloud/storage/template/TemplateConstants.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.storage.template;

public final class TemplateConstants {
    public static final String DEFAULT_TMPLT_ROOT_DIR = "template";
    public static final String DEFAULT_SNAPSHOT_ROOT_DIR = "snapshots";
    public static final String DEFAULT_VOLUME_ROOT_DIR = "volumes";
    public static final String DEFAULT_TMPLT_FIRST_LEVEL_DIR = "tmpl/";

    public static final String DEFAULT_SYSTEM_VM_TEMPLATE_PATH = "template/tmpl/1/";

    public static final int DEFAULT_TMPLT_COPY_PORT = 80;
    public static final String DEFAULT_TMPLT_COPY_INTF = "eth2";
    public static final String TMPLT_COPY_INTF_PRIVATE = "eth1";

    public static final String DEFAULT_HTTP_AUTH_USER = "cloud";

}
